@@ -1,7 +1,5 @@
 /* This is the script for undocked devtools in Vivaldi */
 
-/*eslint-disable no-undef*/
-
 let _theWebview;
 let _inspectingTabId;
 
@@ -40,7 +38,7 @@ function detachWebViewListeners() {
 
 function attachDevtoolsListeners() {
   vivaldi.devtoolsPrivate.onDockingStateChanged.addListener(
-    onDockingStateChanged
+    onDockingStateChanged,
   );
   vivaldi.devtoolsPrivate.onClosed.addListener(onDevtoolsClosed);
   vivaldi.devtoolsPrivate.onActivateWindow.addListener(onActivateWindow);
@@ -48,7 +46,7 @@ function attachDevtoolsListeners() {
 
 function detachDevtoolsListeners() {
   vivaldi.devtoolsPrivate.onDockingStateChanged.removeListener(
-    onDockingStateChanged
+    onDockingStateChanged,
   );
   vivaldi.devtoolsPrivate.onClosed.removeListener(onDevtoolsClosed);
   vivaldi.devtoolsPrivate.onActivateWindow.removeListener(onActivateWindow);
